//////////////////////////////////////////////////////////////
// install.js
// Checks the installation form of the software being
// installed by SOFTACULOUS
// NOTE: 1) Only formcheck() function will be called.
//       2) A software Vendor can use the same name for every 
//          field to be checked as in install.xml . It can be
//          called using $('fieldname').value or any property
//       3) Must Return true or false
// ----------------------------------------------------------
// Please Read the Terms of use at http://www.softaculous.com
// ----------------------------------------------------------
// (c)Softaculous Inc.
//////////////////////////////////////////////////////////////

// Check if there is a hyphen - in prefixed or random generated username ? 
function update_username(){
	
	if(typeof jQuery('#admin_username').val() == "undefined"){
		setTimeout('update_username();', 500);
		return;
	}
	
	var admin_username = jQuery('#admin_username').val();
	var has_dash = admin_username.includes("-");
	
	if(has_dash){
		admin_username = admin_username.replace("-", ""); 
		jQuery('#admin_username').val(admin_username);
	}
}

update_username();

function formcheck(){
	
	//Check the Admin Email
	if(window.check_punycode){
		if(!check_punycode($('admin_email').value)){
			alert('{{err_ademail}}');
			return false;
		}
		return true;
	}
	
	return true;
};